@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
- *                  NetPerfMeter -- Network Performance Meter                 
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
+ *                  NetPerfMeter -- Network Performance Meter
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,11 +23,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
-
 #include "flowbandwidthstats.h"
 
 
@@ -54,7 +59,7 @@ FlowBandwidthStats operator+(const FlowBandwidthStats& s1,
    result.LostBytes          = s1.LostBytes + s2.LostBytes;
    result.LostPackets        = s1.LostPackets + s2.LostPackets;
    result.LostFrames         = s1.LostFrames + s2.LostFrames;
-   return(result);
+   return result;
 }
 
 
@@ -74,7 +79,7 @@ FlowBandwidthStats operator-(const FlowBandwidthStats& s1,
    result.LostBytes          = s1.LostBytes - s2.LostBytes;
    result.LostPackets        = s1.LostPackets - s2.LostPackets;
    result.LostFrames         = s1.LostFrames - s2.LostFrames;
-   return(result);
+   return result;
 }
 
 
@@ -110,38 +115,38 @@ void FlowBandwidthStats::print(std::ostream& os,
    const unsigned long long lostFrames            = LostFrames;
    const unsigned long long lostFrameRate         = calculateRate(lostFrames, receptionDuration);
 
-   os << "      - Transmission:"         << std::endl
-      << "         * Duration:         " << transmissionDuration << " s" << std::endl
-      << "         * Bytes:            " << transmittedBytes << " B\t-> "
-                                         << transmittedByteRate << " B/s" << std::endl
-      << "         * Bits:             " << transmittedBits << " bit\t-> "
-                                         << transmittedBitRate << " bit/s" << std::endl
-      << "         * Packets:          " << transmittedPackets << " packets\t-> "
-                                         << transmittedPacketRate << " packets/s" << std::endl
-      << "         * Frames:           " << transmittedFrames << " frames\t-> "
-                                         << transmittedFrameRate << " frames/s" << std::endl;
+   os << " - Transmission:\n"
+      << "  * Duration:         " << transmissionDuration << " s\n"
+      << "  * Bytes:            " << transmittedBytes << " B\t-> "
+                                         << transmittedByteRate << " B/s\n"
+      << "  * Bits:             " << transmittedBits << " bit\t-> "
+                                         << transmittedBitRate << " bit/s\n"
+      << "  * Packets:          " << transmittedPackets << " packets\t-> "
+                                         << transmittedPacketRate << " packets/s\n"
+      << "  * Frames:           " << transmittedFrames << " frames\t-> "
+                                         << transmittedFrameRate << " frames/s\n";
 
-   os << "      - Reception:"            << std::endl
-      << "         * Duration:         " << receptionDuration << "s" << std::endl
-      << "         * Bytes:            " << receivedBytes << " B\t-> "
-                                         << receivedByteRate << " B/s" << std::endl
-      << "         * Bits:             " << receivedBits << " bit\t-> "
-                                         << receivedBitRate << " bit/s" << std::endl
-      << "         * Packets:          " << receivedPackets << " packets\t-> "
-                                         << receivedPacketRate << " packets/s" << std::endl
-      << "         * Frames:           " << receivedFrames << " frames\t-> "
-                                         << receivedFrameRate << " frames/s" << std::endl;
+   os << " - Reception:\n"
+      << "  * Duration:         " << receptionDuration << "s\n"
+      << "  * Bytes:            " << receivedBytes << " B\t-> "
+                                         << receivedByteRate << " B/s\n"
+      << "  * Bits:             " << receivedBits << " bit\t-> "
+                                         << receivedBitRate << " bit/s\n"
+      << "  * Packets:          " << receivedPackets << " packets\t-> "
+                                         << receivedPacketRate << " packets/s\n"
+      << "  * Frames:           " << receivedFrames << " frames\t-> "
+                                         << receivedFrameRate << " frames/s\n";
 
-   os << "      - Loss:"                 << std::endl
-      << "         * Duration:         " << receptionDuration << "s" << std::endl
-      << "         * Bytes:            " << lostBytes << " B\t-> "
-                                         << lostByteRate << " B/s" << std::endl
-      << "         * Bits:             " << lostBits << " bit\t-> "
-                                         << lostBitRate << " bit/s" << std::endl
-      << "         * Packets:          " << lostPackets << " packets\t-> "
-                                         << lostPacketRate << " packets/s" << std::endl
-      << "         * Frames:           " << lostFrames << " frames\t-> "
-                                         << lostFrameRate << " frames/s" << std::endl;
+   os << " - Loss:\n"
+      << "  * Duration:         " << receptionDuration << "s\n"
+      << "  * Bytes:            " << lostBytes << " B\t-> "
+                                         << lostByteRate << " B/s\n"
+      << "  * Bits:             " << lostBits << " bit\t-> "
+                                         << lostBitRate << " bit/s\n"
+      << "  * Packets:          " << lostPackets << " packets\t-> "
+                                         << lostPacketRate << " packets/s\n"
+      << "  * Frames:           " << lostFrames << " frames\t-> "
+                                         << lostFrameRate << " frames/s\n";
 }
 
 
