@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
  *                  NetPerfMeter -- Network Performance Meter
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -50,15 +56,23 @@ void FlowTrafficSpec::showEntry(std::ostream& os,
                   valueArray[0]);
        break;
       case RANDOM_EXPONENTIAL:
-         snprintf((char*)&str, sizeof(str), "%1.6lf (neg. exp.)",
+         snprintf((char*)&str, sizeof(str), "mean=%1.6lf (neg. exp.)",
                   valueArray[0]);
        break;
       case RANDOM_UNIFORM:
-         snprintf((char*)&str, sizeof(str), "%1.6lf +/- %1.3lf%% (uniform)",
-                  valueArray[0], 100.0 * valueArray[1]);
+         snprintf((char*)&str, sizeof(str), "internal=[%1.6lf, %1.3lf) (uniform)",
+                  valueArray[0], valueArray[1]);
        break;
       case RANDOM_PARETO:
-         snprintf((char*)&str, sizeof(str), "m=%1.6lf, k=%1.6lf%% (pareto)",
+         snprintf((char*)&str, sizeof(str), "location=%1.6lf, shape=%1.6lf (pareto)",
+                  valueArray[0], valueArray[1]);
+       break;
+      case RANDOM_NORMAL:
+         snprintf((char*)&str, sizeof(str), "mean=%1.6lf, stddev=%1.6lf (normal)",
+                  valueArray[0], valueArray[1]);
+       break;
+      case RANDOM_TRUNCATED_NORMAL:
+         snprintf((char*)&str, sizeof(str), "mean=%1.6lf, stddev=%1.6lf (truncated normal)",
                   valueArray[0], valueArray[1]);
        break;
       default:
@@ -73,34 +87,27 @@ void FlowTrafficSpec::showEntry(std::ostream& os,
 // ###### Print FlowTrafficSpec #############################################
 void FlowTrafficSpec::print(std::ostream& os) const
 {
-   os << "      - Receive Buffer Size: "
-      << RcvBufferSize << std::endl;
-   os << "      - Send Buffer Size:    "
-      << SndBufferSize << std::endl;
-   os << "      - Max. Message Size:   "
-      << MaxMsgSize << std::endl;
-   os << "      - Defragment Timeout:  "
-      << DefragmentTimeout / 1000 << "ms" << std::endl;
-   os << "      - Outbound Frame Rate: ";
+   os << " - Receive Buffer Size: " << RcvBufferSize << "\n";
+   os << " - Send Buffer Size:    " << SndBufferSize << "\n";
+   os << " - Max. Message Size:   " << MaxMsgSize << "\n";
+   os << " - Defragment Timeout:  " << DefragmentTimeout / 1000 << "ms\n";
+   os << " - Outbound Frame Rate: ";
    showEntry(os, (const double*)&OutboundFrameRate, OutboundFrameRateRng);
-   os << std::endl;
-   os << "      - Outbound Frame Size: ";
+   os << "\n - Outbound Frame Size: ";
    showEntry(os, (const double*)&OutboundFrameSize, OutboundFrameSizeRng);
-   os << std::endl;
-   os << "      - Inbound Frame Rate:  ";
+   os << "\n - Inbound Frame Rate:  ";
    showEntry(os, (const double*)&InboundFrameRate, InboundFrameRateRng);
-   os << std::endl;
-   os << "      - Inbound Frame Size:  ";
+   os << "\n - Inbound Frame Size:  ";
    showEntry(os, (const double*)&InboundFrameSize, InboundFrameSizeRng);
-   os << std::endl;
+   os << "\n";
    if(Protocol == IPPROTO_SCTP) {
       char ordered[32];
       char reliable[32];
-      snprintf((char*)&ordered, sizeof(ordered), "%1.2f%%", 100.0 * OrderedMode);
-      snprintf((char*)&reliable, sizeof(reliable), "%1.2f%%", 100.0 * ReliableMode);
-      os << "      - Ordered Mode:        " << ordered  << std::endl;
-      os << "      - Reliable Mode:       " << reliable << std::endl;
-      os << "      - Retransmissions:     ";
+      snprintf((char*)&ordered, sizeof(ordered), "%1.3f%%", 100.0 * OrderedMode);
+      snprintf((char*)&reliable, sizeof(reliable), "%1.3f%%", 100.0 * ReliableMode);
+      os << " - Ordered Mode:        " << ordered  << "\n";
+      os << " - Reliable Mode:       " << reliable << "\n";
+      os << " - Retransmissions:     ";
       if( (RetransmissionTrialsInMS) && (RetransmissionTrials == ~((uint32_t)0)) ) {
          os << "unlimited";
       }
@@ -108,15 +115,15 @@ void FlowTrafficSpec::print(std::ostream& os) const
          os << RetransmissionTrials
             << (RetransmissionTrialsInMS ? "ms" : " trials");
       }
-      os << std::endl;
+      os << "\n";
    }
 
-   os << "      - On/Off:              {";
+   os << " - On/Off:              { ";
    if(OnOffEvents.size() > 0) {
       bool start = true;
       for(std::vector<OnOffEvent>::const_iterator iterator = OnOffEvents.begin();
           iterator != OnOffEvents.end();iterator++) {
-         os << std::endl << "         " << ((start == true) ? "* " : "~ ");
+         os << "\n" << "         " << ((start == true) ? "🟢on:  " : "🔴off: ");
          showEntry(os, (const double*)&(*iterator).ValueArray, (*iterator).RandNumGen);
          start = !start;
       }
@@ -124,40 +131,50 @@ void FlowTrafficSpec::print(std::ostream& os) const
    else {
       os << "*0 ";
    }
-   os << "}" << std::endl
-      << "      - Repeat On/Off:       " << ((RepeatOnOff == true) ? "yes" : "no") << std::endl;
+   os << "}\n"
+      << " - Repeat On/Off:       " << ((RepeatOnOff == true) ? "yes" : "no") << "\n";
 
-   os << "      - Error on Abort:      "
-      << ((ErrorOnAbort == true) ? "yes" : "no") << std::endl
-      << "      - Debug:               "
-      << ((Debug == true) ? "yes" : "no") << std::endl
-      << "      - No Delay:            "
-      << ((NoDelay == true) ? "yes" : "no") << std::endl
-      << "      Congestion Control:    " << CongestionControl << std::endl
-      << "      Number of Diff. Ports: " << NDiffPorts        << std::endl
-      << "      Path Manager:          " << PathMgr           << std::endl
-      << "      Scheduler:             " << Scheduler         << std::endl;
-
-   os << "      - CMT:                 #" << (unsigned int)CMT << " ";
-   switch(CMT) {
-      case NPAF_PRIMARY_PATH:
-         os << "(off)";
-       break;
-      case NPAF_CMT:
-         os << "(CMT)";
-       break;
-      case NPAF_CMTRPv1:
-         os << "(CMT/RPv1)";
-       break;
-      case NPAF_CMTRPv2:
-         os << "(CMT/RPv2)";
-       break;
-      case NPAF_LikeMPTCP:
-         os << "(MPTCP)";
-       break;
+   os << " - Error on Abort:      "
+      << ((ErrorOnAbort == true) ? "yes" : "no") << "\n";
+   if( (Protocol == IPPROTO_SCTP) || (Protocol == IPPROTO_TCP)
+#ifdef HAVE_MPTCP
+       || (Protocol == IPPROTO_MPTCP)
+#endif
+     ) {
+      os << " - No Delay:            "
+         << ((NoDelay == true) ? "yes" : "no") << "\n";
+   }
+   if( (Protocol == IPPROTO_TCP)
+#ifdef HAVE_MPTCP
+       || (Protocol == IPPROTO_MPTCP)
+#endif
+     ) {
+      os << " - Congestion Control:  " << CongestionControl << "\n";
+   }
+   if(Protocol == IPPROTO_SCTP) {
+      os << " - CMT:                 #" << (unsigned int)CMT << " ";
+      switch(CMT) {
+         case NPAF_PRIMARY_PATH:
+            os << "(off)";
+         break;
+         case NPAF_CMT:
+            os << "(CMT)";
+         break;
+         case NPAF_CMTRPv1:
+            os << "(CMT/RPv1)";
+         break;
+         case NPAF_CMTRPv2:
+            os << "(CMT/RPv2)";
+         break;
+         case NPAF_LikeMPTCP:
+            os << "(MPTCP)";
+         break;
+      }
+      os << "\n";
+   }
+   if(Protocol == IPPROTO_DCCP) {
+      os << " - CCID:                #" << (unsigned int)CCID << "\n";
    }
-   os << std::endl;
-   os << "      - CCID:                #" << (unsigned int)CCID << std::endl;
 }
 
 
@@ -177,9 +194,6 @@ void FlowTrafficSpec::reset()
    NoDelay                  = false;
    BindV6Only               = false;
    RepeatOnOff              = false;
-   NDiffPorts               = 4;
-   PathMgr                  = "fullmesh";
-   Scheduler                = "default";
    CongestionControl        = "default";
    CMT                      = 0x00;
    CCID                     = 0x00;
