@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
  *                  NetPerfMeter -- Network Performance Meter
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -25,6 +31,7 @@
 #define FLOWTRAFFICSPEC_H
 
 #include "netperfmeterpackets.h"
+#include "tools.h"
 
 #include <sys/types.h>
 
@@ -50,6 +57,15 @@ class FlowTrafficSpec
    void print(std::ostream& os) const;
    void reset();
 
+   inline bool outgoingFlowIsSaturated() const {
+      return ( (OutboundFrameRateRng == RANDOM_CONSTANT) &&
+               (OutboundFrameRate[0] <= 0.000000001)     &&
+               (OutboundFrameSize[0] > 0.000000001) );
+   }
+   inline bool outgoingFlowIsNotSaturated() const {
+      return ( (OutboundFrameRate[0] > 0.000000001) &&
+               (OutboundFrameSize[0] > 0.000000001) );
+   }
 
    // ====== Public Data ====================================================
    public:
@@ -81,11 +97,7 @@ class FlowTrafficSpec
 
    uint8_t                 CMT;
    uint8_t                 CCID;
-
-   uint16_t                NDiffPorts;
    std::string             CongestionControl;
-   std::string             PathMgr;
-   std::string             Scheduler;
 
    bool                    Debug;
    bool                    NoDelay;
