@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
- *                  NetPerfMeter -- Network Performance Meter                 
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
+ *                  NetPerfMeter -- Network Performance Meter
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -50,19 +56,19 @@ class InputFile
    bool finish(const bool closeFile = true);
 
    inline bool exists() const {
-      return(File || BZFile);
+      return File || BZFile;
    }
    inline InputFileFormat getFormat() const {
-      return(Format);
+      return Format;
    }
    inline FILE* getFile() const {
-      return(File);
+      return File;
    }
    inline const std::string& getName() const {
-      return(Name);
+      return Name;
    }
    inline unsigned long long getLine() const {
-      return(Line);
+      return Line;
    }
    ssize_t readLine(char* buffer, size_t bufferSize, bool& eof);
 
