@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
- *                  NetPerfMeter -- Network Performance Meter                 
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
+ *                  NetPerfMeter -- Network Performance Meter
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -40,25 +46,26 @@ class Measurement : public Mutex
    ~Measurement();
 
    const uint64_t getMeasurementID() const {
-      return(MeasurementID);
+      return MeasurementID;
    }
    const std::string& getVectorNamePattern() const {
-      return(VectorNamePattern);
+      return VectorNamePattern;
    }
    const OutputFile& getVectorFile() const {
-      return(VectorFile);
+      return VectorFile;
    }
    const std::string& getScalarNamePattern() const {
-      return(ScalarNamePattern);
+      return ScalarNamePattern;
    }
    const OutputFile& getScalarFile() const {
-      return(ScalarFile);
+      return ScalarFile;
    }
    inline unsigned long long getFirstStatisticsEvent() const {
-      return(FirstStatisticsEvent);
+      return FirstStatisticsEvent;
    }
 
    bool initialize(const unsigned long long now,
+                   const int                controlSocketDescriptor,
                    const uint64_t           measurementID,
                    const char*              vectorNamePattern,
                    const OutputFileFormat   vectorFileFormat,
@@ -74,6 +81,7 @@ class Measurement : public Mutex
 
    // ====== Private Data ===================================================
    private:
+   int                ControlSocketDescriptor;
    uint64_t           MeasurementID;
    unsigned long long StatisticsInterval;
    unsigned long long FirstStatisticsEvent;
