@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
- *                  NetPerfMeter -- Network Performance Meter                 
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
+ *                  NetPerfMeter -- Network Performance Meter
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -44,20 +50,21 @@ class MessageReader
 
    bool registerSocket(const int    protocol,
                        const int    sd,
+                       const bool   mustBeNew      = true,
                        const size_t maxMessageSize = 65535);
    bool deregisterSocket(const int sd);
 
    ssize_t receiveMessage(const int        sd,
                           void*            buffer,
                           size_t           bufferSize,
-                          sockaddr*        from     = NULL,
-                          socklen_t*       fromSize = NULL,
-                          sctp_sndrcvinfo* sinfo    = NULL,
-                          int*             msgFlags = NULL);
+                          sockaddr*        from     = nullptr,
+                          socklen_t*       fromSize = nullptr,
+                          int64_t*         streamID = nullptr,
+                          int*             msgFlags = nullptr);
    size_t getAllSDs(int* sds, const size_t maxEntries);
-   
+
    inline size_t size() {
-      return(SocketMap.size()); 
+      return SocketMap.size();
    }
 
    // ====== Private Data ===================================================
@@ -87,9 +94,9 @@ class MessageReader
    inline Socket* getSocket(const int sd) {
       std::map<int, Socket*>::iterator found = SocketMap.find(sd);
       if(found != SocketMap.end()) {
-         return(found->second);
+         return found->second;
       }
-      return(NULL);
+      return nullptr;
    }
 
    std::map<int, Socket*> SocketMap;
