@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
- *                  NetPerfMeter -- Network Performance Meter                 
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
+ *                  NetPerfMeter -- Network Performance Meter
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -39,6 +45,8 @@ struct NetPerfMeterHeader
 #define PPID_NETPERFMETER_CONTROL   36           /* Old value: 0x29097605 */
 #define PPID_NETPERFMETER_DATA      37           /* Old value: 0x29097606 */
 #define SC_NETPERFMETER_DATA        1852861808   /* Old value: 0x29097606 */
+#define ALPN_NETPERFMETER_CONTROL   "netperfmeter/control"
+#define ALPN_NETPERFMETER_DATA      "netperfmeter/data"
 
 
 #define NETPERFMETER_ACKNOWLEDGE    0x01
@@ -91,8 +99,7 @@ struct NetPerfMeterAddFlowMessage
    uint32_t               FlowID;
    uint64_t               MeasurementID;
    uint16_t               StreamID;
-   uint8_t                Protocol;
-   uint8_t                pad;
+   uint16_t               Protocol;   // Little Endian, due to compatibility!
 
    char                   Description[NETPERFMETER_DESCRIPTION_SIZE];
 
@@ -112,10 +119,10 @@ struct NetPerfMeterAddFlowMessage
    uint8_t                CMT;
    uint8_t                CCID;
 
-   uint16_t               NDiffPorts;
-   char                   PathMgr[NETPERFMETER_PATHMGR_LENGTH];
+   uint16_t               NDiffPorts;                                 // obsolete!
+   char                   PathMgr[NETPERFMETER_PATHMGR_LENGTH];       // obsolete!
    char                   CongestionControl[NETPERFMETER_CC_LENGTH];
-   char                   Scheduler[NETPERFMETER_SCHEDULER_LENGTH];
+   char                   Scheduler[NETPERFMETER_SCHEDULER_LENGTH];   // obsolete!
 
    uint16_t               OnOffEvents;
    NetPerfMeterOnOffEvent OnOffEvent[];
@@ -126,7 +133,8 @@ struct NetPerfMeterAddFlowMessage
 #define NPMAFF_REPEATONOFF   (1 << 2)
 
 // RetransmissionTrials in milliseconds (highest bit of 32-bit value set)
-#define NPMAF_RTX_TRIALS_IN_MILLISECONDS (1 << 31)
+#define NPMAF_RTX_TRIALS_IN_MILLISECONDS (1U << 31)    // Use ms instead of number of trials
+#define NPMAF_RTX_DEFAULT                0x7fffffffU   // Use protocol default
 
 #define NPAF_PRIMARY_PATH 0x00
 #define NPAF_CMT          0x01
