@@ -1,6 +1,6 @@
 # ###########################################################################
 #             Thomas Dreibholz's R Simulation Scripts Collection
-#                  Copyright (C) 2005-2024 Thomas Dreibholz
+#                  Copyright (C) 2005-2026 Thomas Dreibholz
 #
 #               Author: Thomas Dreibholz, thomas.dreibholz@gmail.com
 # ###########################################################################
@@ -624,7 +624,7 @@ plotstd3 <- function(mainTitle,
 
                      if((type == "lx") || (type=="linesx")) {
                         lines(xSubset, ySubset,
-                              lwd=par("cex"), col=legendColor, lty=legendStyle, lwd=lineWidth*par("cex"), pch=getDot(dotSet, legendDot))
+                              col=legendColor, lty=legendStyle, lwd=lineWidth*par("cex"), pch=getDot(dotSet, legendDot))
                      }
                      else if((type == "sx") || (type=="stepsx")) {
                         lines(xSubset, ySubset, type="s",
@@ -633,9 +633,9 @@ plotstd3 <- function(mainTitle,
 
                      pcex <- dotScaleFactor * par("cex")
                      points(xSubset, ySubset,
-                           col=legendColor, lty=legendStyle, pch=getDot(dotSet, legendDot),
-                           lwd=par("cex"),
-                           cex=pcex, bg="yellow")
+                            col=legendColor, lty=legendStyle, pch=getDot(dotSet, legendDot),
+                            lwd=par("cex"),
+                            cex=pcex, bg="yellow")
 
                      legendTexts  <- append(legendTexts,  legendText)
                      legendColors <- append(legendColors, legendColor)
@@ -873,16 +873,18 @@ plotstd3 <- function(mainTitle,
          legendColors <- par("fg")
          legendBackground <- "white"
       }
-      legend(lx, ly,
-             xjust = lxjust,
-             yjust = lyjust,
-             parse(text=legendTexts),
-             bg=legendBackground,
-             col=legendColors,
-             lty=legendStyles,
-             pch=legendDots,
-             text.col=legendColors,
-             lwd=1, cex=par("cex")*legendSize)
+      if(length(legendTexts) > 1) {
+         legend(lx, ly,
+                xjust = lxjust,
+                yjust = lyjust,
+                parse(text=legendTexts),
+                bg=legendBackground,
+                col=legendColors,
+                lty=legendStyles,
+                pch=legendDots,
+                text.col=legendColors,
+                lwd=1, cex=par("cex")*legendSize)
+      }
    }
 
    par(opar)
@@ -1842,13 +1844,13 @@ createPlots <- function(simulationDirectory,
 
 
       # ------ Set x/y-axis ticks -------------------------------------------
-      if((length(xAxisTicks) < 2) || (is.na(xAxisTicks))) {
+      if(length(xAxisTicks) < 2) {
          xAxisTicks <- getUsefulTicks(xSet)
       }
-      if((length(yAxisTicks) < 2) || (is.na(yAxisTicks))) {
+      if(length(yAxisTicks) < 2) {
          yAxisTicks <- getUsefulTicks(ySet)
       }
-      if((length(legendPos) < 2) || (is.na(legendPos))) {
+      if(length(legendPos) < 2) {
          legendPos <- c(1,1)
       }
 
