@@ -1,7 +1,13 @@
 /*
  * ==========================================================================
+ *         _   _      _   ____            __ __  __      _
+ *        | \ | | ___| |_|  _ \ ___ _ __ / _|  \/  | ___| |_ ___ _ __
+ *        |  \| |/ _ \ __| |_) / _ \ '__| |_| |\/| |/ _ \ __/ _ \ '__|
+ *        | |\  |  __/ |_|  __/  __/ |  |  _| |  | |  __/ ||  __/ |
+ *        |_| \_|\___|\__|_|   \___|_|  |_| |_|  |_|\___|\__\___|_|
+ *
  *                  NetPerfMeter -- Network Performance Meter
- *                 Copyright (C) 2009-2024 by Thomas Dreibholz
+ *                 Copyright (C) 2009-2026 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -17,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact:  thomas.dreibholz@gmail.com
+ * Contact:  dreibh@simula.no
  * Homepage: https://www.nntb.no/~dreibh/netperfmeter/
  */
 
@@ -25,7 +31,7 @@
 #define TOOLS_H
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <stdio.h>
@@ -47,39 +53,24 @@
 #include "mutex.h"
 
 
-/* MPTCP as "pseudo-protocol". Just for internal representation. */
-#ifndef IPPROTO_MPTCP
-#define IPPROTO_MPTCP IPPROTO_EGP   // 262
+// MPTCP definitions
+#ifdef HAVE_MPTCP
+#include <linux/mptcp.h>
 #endif
 
+// QUIC definitions
+#ifdef HAVE_QUIC
+extern "C" {
+#include <netinet/quic.h>
+}
+// #else
+// #warning QUIC is not supported by the API of this system!
+#endif
 
-/* FIXME: This is ugly, but currently the only way to easily get the #defines for Linux MPTCP! */
-#define MPTCP_ENABLED               42
-#define MPTCP_SCHEDULER             43
-#define MPTCP_PATH_MANAGER          44
-#define MPTCP_INFO                  45
-#define MPTCP_DEBUG                 46
-#define MPTCP_NDIFFPORTS            47
-
-#define MPTCP_ENABLED_LEGACY        10002
-#define MPTCP_SCHEDULER_LEGACY      10009
-#define MPTCP_PATH_MANAGER_LEGACY   10008
-#define MPTCP_DEBUG_LEGACY          10001
-#define MPTCP_NDIFFPORTS_LEGACY     10007
-
-
-/* DCCP definitions */
+// DCCP definitions
 #ifdef HAVE_DCCP
 #include <linux/dccp.h>
-#ifndef SOL_DCCP
-#define SOL_DCCP 269
 #endif
-// #else
-// #warning DCCP is not supported by the API of this system!
-#endif
-
-
-extern Mutex gOutputMutex;
 
 
 std::string format(const char* fmt, ...);
@@ -139,14 +130,6 @@ int bindSocket(const int             sd,
                const sockaddr_union* localAddressArray,
                const bool            listenMode,
                const bool            bindV6Only);
-int createAndBindSocket(const int             family,
-                        const int             type,
-                        const int             protocol,
-                        const uint16_t        localPort,
-                        const unsigned int    localAddresses,
-                        const sockaddr_union* localAddressArray,
-                        const bool            listenMode,
-                        const bool            bindV6Only);
 uint64_t hton64(const uint64_t value);
 uint64_t ntoh64(const uint64_t value);
 
@@ -163,10 +146,12 @@ bool breakDetected();
 void sendBreak(const bool quiet);
 
 
-#define RANDOM_CONSTANT    0
-#define RANDOM_UNIFORM     1
-#define RANDOM_EXPONENTIAL 2
-#define RANDOM_PARETO      3
+#define RANDOM_CONSTANT         0
+#define RANDOM_UNIFORM          1
+#define RANDOM_EXPONENTIAL      2
+#define RANDOM_PARETO           3
+#define RANDOM_NORMAL           4
+#define RANDOM_TRUNCATED_NORMAL 5
 
 const char* getRandomGeneratorName(const uint8_t rng);
 double getRandomValue(const double* valueArray, const uint8_t rng);
@@ -175,8 +160,10 @@ uint16_t random16();
 uint64_t random64();
 uint32_t random32();
 double randomDouble();
-double randomExpDouble(const double p);
-double randomParetoDouble(const double m, const double k);
+double randomExpDouble(const double mean);
+double randomNormal(const double mean, const double stddev);
+double randomTruncNormal(const double mean, const double stddev);
+double randomParetoDouble(const double location, const double shape);
 
 #ifdef __APPLE__
 // Apple's poll() function is broken. We need a wrapper to select() here!
@@ -184,27 +171,8 @@ int ext_poll_wrapper(struct pollfd* fdlist, long unsigned int count, int time);
 #else
 inline int ext_poll_wrapper(struct pollfd* fdlist, long unsigned int count, int time)
 {
-   return(ext_poll(fdlist, count, time));
+   return ext_poll(fdlist, count, time);
 }
 #endif
 
-/*
-
-FIXME!
-Commented out the LK-SCTP sctp_send() bug work-around.
-This should be removed once it is clear that no current system is still affected!
-
-#if defined(linux)
-#warning Added fix for broken sctp_send() with LK-SCTP
-ssize_t sctp_send_fixed(int                           sd,
-                        const void*                   data,
-                        size_t                        len,
-                        const struct sctp_sndrcvinfo* sinfo,
-                        int                           flags);
-#define sctp_send(a,b,c,d,e) sctp_send_fixed(a,b,c,d,e)
-#endif
-*/
-
-bool setBufferSizes(int sd, const int sndBufSize, const int rcvBufSize);
-
 #endif
